@@ -29,6 +29,7 @@ __all__ = (
     "ActionTargetTypeDef",
     "ActionTypeDef",
     "CreateExperimentTemplateActionInputTypeDef",
+    "CreateExperimentTemplateLogConfigurationInputTypeDef",
     "CreateExperimentTemplateRequestRequestTypeDef",
     "CreateExperimentTemplateResponseTypeDef",
     "CreateExperimentTemplateStopConditionInputTypeDef",
@@ -37,12 +38,20 @@ __all__ = (
     "DeleteExperimentTemplateResponseTypeDef",
     "ExperimentActionStateTypeDef",
     "ExperimentActionTypeDef",
+    "ExperimentCloudWatchLogsLogConfigurationTypeDef",
+    "ExperimentLogConfigurationTypeDef",
+    "ExperimentS3LogConfigurationTypeDef",
     "ExperimentStateTypeDef",
     "ExperimentStopConditionTypeDef",
     "ExperimentSummaryTypeDef",
     "ExperimentTargetFilterTypeDef",
     "ExperimentTargetTypeDef",
     "ExperimentTemplateActionTypeDef",
+    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
+    "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
+    "ExperimentTemplateLogConfigurationTypeDef",
+    "ExperimentTemplateS3LogConfigurationInputTypeDef",
+    "ExperimentTemplateS3LogConfigurationTypeDef",
     "ExperimentTemplateStopConditionTypeDef",
     "ExperimentTemplateSummaryTypeDef",
     "ExperimentTemplateTargetFilterTypeDef",
@@ -56,6 +65,8 @@ __all__ = (
     "GetExperimentResponseTypeDef",
     "GetExperimentTemplateRequestRequestTypeDef",
     "GetExperimentTemplateResponseTypeDef",
+    "GetTargetResourceTypeRequestRequestTypeDef",
+    "GetTargetResourceTypeResponseTypeDef",
     "ListActionsRequestRequestTypeDef",
     "ListActionsResponseTypeDef",
     "ListExperimentTemplatesRequestRequestTypeDef",
@@ -64,14 +75,20 @@ __all__ = (
     "ListExperimentsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTargetResourceTypesRequestRequestTypeDef",
+    "ListTargetResourceTypesResponseTypeDef",
     "ResponseMetadataTypeDef",
     "StartExperimentRequestRequestTypeDef",
     "StartExperimentResponseTypeDef",
     "StopExperimentRequestRequestTypeDef",
     "StopExperimentResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
+    "TargetResourceTypeParameterTypeDef",
+    "TargetResourceTypeSummaryTypeDef",
+    "TargetResourceTypeTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateExperimentTemplateActionInputItemTypeDef",
+    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
     "UpdateExperimentTemplateRequestRequestTypeDef",
     "UpdateExperimentTemplateResponseTypeDef",
     "UpdateExperimentTemplateStopConditionInputTypeDef",
@@ -143,6 +160,29 @@ class CreateExperimentTemplateActionInputTypeDef(
     pass
 
 
+_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "logSchemaVersion": int,
+    },
+)
+_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
+        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateExperimentTemplateLogConfigurationInputTypeDef(
+    _RequiredCreateExperimentTemplateLogConfigurationInputTypeDef,
+    _OptionalCreateExperimentTemplateLogConfigurationInputTypeDef,
+):
+    pass
+
+
 _RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
     "_RequiredCreateExperimentTemplateRequestRequestTypeDef",
     {
@@ -158,6 +198,7 @@ _OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
     {
         "targets": Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"],
         "tags": Mapping[str, str],
+        "logConfiguration": "CreateExperimentTemplateLogConfigurationInputTypeDef",
     },
     total=False,
 )
@@ -213,6 +254,7 @@ _OptionalCreateExperimentTemplateTargetInputTypeDef = TypedDict(
         "resourceArns": Sequence[str],
         "resourceTags": Mapping[str, str],
         "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
+        "parameters": Mapping[str, str],
     },
     total=False,
 )
@@ -264,6 +306,33 @@ ExperimentActionTypeDef = TypedDict(
     total=False,
 )
 
+ExperimentCloudWatchLogsLogConfigurationTypeDef = TypedDict(
+    "ExperimentCloudWatchLogsLogConfigurationTypeDef",
+    {
+        "logGroupArn": str,
+    },
+    total=False,
+)
+
+ExperimentLogConfigurationTypeDef = TypedDict(
+    "ExperimentLogConfigurationTypeDef",
+    {
+        "cloudWatchLogsConfiguration": "ExperimentCloudWatchLogsLogConfigurationTypeDef",
+        "s3Configuration": "ExperimentS3LogConfigurationTypeDef",
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
+ExperimentS3LogConfigurationTypeDef = TypedDict(
+    "ExperimentS3LogConfigurationTypeDef",
+    {
+        "bucketName": str,
+        "prefix": str,
+    },
+    total=False,
+)
+
 ExperimentStateTypeDef = TypedDict(
     "ExperimentStateTypeDef",
     {
@@ -311,6 +380,7 @@ ExperimentTargetTypeDef = TypedDict(
         "resourceTags": Dict[str, str],
         "filters": List["ExperimentTargetFilterTypeDef"],
         "selectionMode": str,
+        "parameters": Dict[str, str],
     },
     total=False,
 )
@@ -327,6 +397,62 @@ ExperimentTemplateActionTypeDef = TypedDict(
     total=False,
 )
 
+ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef = TypedDict(
+    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
+    {
+        "logGroupArn": str,
+    },
+)
+
+ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef = TypedDict(
+    "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
+    {
+        "logGroupArn": str,
+    },
+    total=False,
+)
+
+ExperimentTemplateLogConfigurationTypeDef = TypedDict(
+    "ExperimentTemplateLogConfigurationTypeDef",
+    {
+        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
+        "s3Configuration": "ExperimentTemplateS3LogConfigurationTypeDef",
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
+_RequiredExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
+    "_RequiredExperimentTemplateS3LogConfigurationInputTypeDef",
+    {
+        "bucketName": str,
+    },
+)
+_OptionalExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
+    "_OptionalExperimentTemplateS3LogConfigurationInputTypeDef",
+    {
+        "prefix": str,
+    },
+    total=False,
+)
+
+
+class ExperimentTemplateS3LogConfigurationInputTypeDef(
+    _RequiredExperimentTemplateS3LogConfigurationInputTypeDef,
+    _OptionalExperimentTemplateS3LogConfigurationInputTypeDef,
+):
+    pass
+
+
+ExperimentTemplateS3LogConfigurationTypeDef = TypedDict(
+    "ExperimentTemplateS3LogConfigurationTypeDef",
+    {
+        "bucketName": str,
+        "prefix": str,
+    },
+    total=False,
+)
+
 ExperimentTemplateStopConditionTypeDef = TypedDict(
     "ExperimentTemplateStopConditionTypeDef",
     {
@@ -373,6 +499,7 @@ ExperimentTemplateTargetTypeDef = TypedDict(
         "resourceTags": Dict[str, str],
         "filters": List["ExperimentTemplateTargetFilterTypeDef"],
         "selectionMode": str,
+        "parameters": Dict[str, str],
     },
     total=False,
 )
@@ -389,6 +516,7 @@ ExperimentTemplateTypeDef = TypedDict(
         "lastUpdateTime": datetime,
         "roleArn": str,
         "tags": Dict[str, str],
+        "logConfiguration": "ExperimentTemplateLogConfigurationTypeDef",
     },
     total=False,
 )
@@ -407,6 +535,7 @@ ExperimentTypeDef = TypedDict(
         "startTime": datetime,
         "endTime": datetime,
         "tags": Dict[str, str],
+        "logConfiguration": "ExperimentLogConfigurationTypeDef",
     },
     total=False,
 )
@@ -456,6 +585,21 @@ GetExperimentTemplateResponseTypeDef = TypedDict(
     },
 )
 
+GetTargetResourceTypeRequestRequestTypeDef = TypedDict(
+    "GetTargetResourceTypeRequestRequestTypeDef",
+    {
+        "resourceType": str,
+    },
+)
+
+GetTargetResourceTypeResponseTypeDef = TypedDict(
+    "GetTargetResourceTypeResponseTypeDef",
+    {
+        "targetResourceType": "TargetResourceTypeTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListActionsRequestRequestTypeDef = TypedDict(
     "ListActionsRequestRequestTypeDef",
     {
@@ -525,6 +669,24 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListTargetResourceTypesRequestRequestTypeDef = TypedDict(
+    "ListTargetResourceTypesRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListTargetResourceTypesResponseTypeDef = TypedDict(
+    "ListTargetResourceTypesResponseTypeDef",
+    {
+        "targetResourceTypes": List["TargetResourceTypeSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -589,6 +751,34 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+TargetResourceTypeParameterTypeDef = TypedDict(
+    "TargetResourceTypeParameterTypeDef",
+    {
+        "description": str,
+        "required": bool,
+    },
+    total=False,
+)
+
+TargetResourceTypeSummaryTypeDef = TypedDict(
+    "TargetResourceTypeSummaryTypeDef",
+    {
+        "resourceType": str,
+        "description": str,
+    },
+    total=False,
+)
+
+TargetResourceTypeTypeDef = TypedDict(
+    "TargetResourceTypeTypeDef",
+    {
+        "resourceType": str,
+        "description": str,
+        "parameters": Dict[str, "TargetResourceTypeParameterTypeDef"],
+    },
+    total=False,
+)
+
 _RequiredUntagResourceRequestRequestTypeDef = TypedDict(
     "_RequiredUntagResourceRequestRequestTypeDef",
     {
@@ -622,6 +812,16 @@ UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     total=False,
 )
 
+UpdateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
+        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
 _RequiredUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateExperimentTemplateRequestRequestTypeDef",
     {
@@ -636,6 +836,7 @@ _OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
         "targets": Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"],
         "actions": Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
         "roleArn": str,
+        "logConfiguration": "UpdateExperimentTemplateLogConfigurationInputTypeDef",
     },
     total=False,
 )
@@ -691,6 +892,7 @@ _OptionalUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
         "resourceArns": Sequence[str],
         "resourceTags": Mapping[str, str],
         "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
+        "parameters": Mapping[str, str],
     },
     total=False,
 )
